@@ -1,5 +1,8 @@
 from enum import IntFlag
 
+class ConnectionType(IntFlag):
+    BT = 0x0,
+    USB = 0x1
 class LedOptions(IntFlag):
     Off=0x0,
     PlayerLedBrightness=0x1,
